create database if not exists `apimngr`;
use `apimngr`;

drop table if exists data_api;
CREATE TABLE `data_api` (
                            `id` int NOT NULL AUTO_INCREMENT COMMENT '主键自增',
                            `api_name` varchar(50) NOT NULL COMMENT '接口名称',
                            `api_key` varchar(50) NOT NULL COMMENT '唯一关键词',
                            `api_type` int DEFAULT '0' COMMENT '接口类别 0-报表 1-常规 2-第三方接口',
                            `category_id` int DEFAULT '0' COMMENT '接口分类id,关联 data_api_category表',
                            `api_formal` int DEFAULT '0' COMMENT '接口类型 1-正式 0-临时',
                            `api_url` varchar(300) DEFAULT NULL COMMENT '接口地址',
                            `datasource_id` int DEFAULT '0' COMMENT '数据源id',
                            `query_table` varchar(200) DEFAULT NULL COMMENT '查询表视图名称',
                            `query_param` text CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci COMMENT '查询条件',
                            `query_sql` text COMMENT '查询sql语句',
                            `api_status` int DEFAULT '0' COMMENT '接口状态 0-下线 1-上线 2-故障',
                            `login_required` int DEFAULT '0' COMMENT '是否需要登录 0-不需要 1-需要',
                            `pid` int DEFAULT NULL COMMENT '二级分类id',
                            `note` text COMMENT '扩展字段',
                            `remark` varchar(100) DEFAULT NULL COMMENT '备注',
                            `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                            `api_method` varchar(10) DEFAULT NULL COMMENT 'API接口请求方式(POST/GET)',
                            `api_headers` text COMMENT 'API接口请求头JSON',
                            `api_js_function` text COMMENT 'API接口返回数据解析js函数',
                            `api_param_type` tinyint DEFAULT '0' COMMENT 'API接口参数传递方式（0:json/1:x-www-form-urlencoded）',
                            `chart_type` tinyint DEFAULT NULL COMMENT '图表类型',
                            `create_user_id` bigint DEFAULT NULL COMMENT '创建人ID',
                            `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
                            `is_page` tinyint NOT NULL DEFAULT '0' COMMENT '是否分页',
                            `page_size` tinyint DEFAULT NULL COMMENT '分页数量',
                            PRIMARY KEY (`id`),
                            UNIQUE KEY `api_key` (`api_key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;


drop table if exists data_api_category;
CREATE TABLE `data_api_category` (
                                     `id` int NOT NULL AUTO_INCREMENT COMMENT '主键 自增',
                                     `pid` int DEFAULT NULL COMMENT 'pid',
                                     `order_index` int NOT NULL DEFAULT '0' COMMENT '排序值，从小到大排',
                                     `category_name` varchar(50) NOT NULL COMMENT '指标分类名称',
                                     `remark` varchar(100) DEFAULT NULL COMMENT '备注',
                                     `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                     `create_user_id` bigint DEFAULT NULL COMMENT '创建人ID',
                                     `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
                                     PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci ROW_FORMAT=DYNAMIC;

drop table if exists report_datasource;
CREATE TABLE `report_datasource` (
                                     `id` int NOT NULL AUTO_INCREMENT COMMENT '主键自增',
                                     `ds_ip` varchar(50) DEFAULT NULL COMMENT 'ip地址',
                                     `ds_port` int DEFAULT NULL COMMENT '端口',
                                     `ds_db` varchar(50) DEFAULT NULL COMMENT '数据库名/SID',
                                     `url` varchar(300) DEFAULT NULL COMMENT '连接url',
                                     `pool_name` varchar(50) NOT NULL COMMENT '连接名称',
                                     `driver_class_name` varchar(50) DEFAULT NULL COMMENT 'driverClassName',
                                     `ds_user` varchar(50) DEFAULT NULL COMMENT '用户名',
                                     `ds_password` varchar(50) DEFAULT NULL COMMENT '密码',
                                     `ds_type` int DEFAULT NULL COMMENT '数据源类型 0-mysql 1-oracle 2-sqlserver 3-postgresql 4-clickhouse',
                                     `is_deleted` int DEFAULT '0',
                                     `remark` varchar(200) DEFAULT NULL COMMENT '备注',
                                     `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                     `create_user_id` bigint DEFAULT NULL COMMENT '创建人ID',
                                     `responsible_person_id` bigint DEFAULT NULL COMMENT '责任人ID',
                                     `responsible_person_name` varchar(50) DEFAULT NULL COMMENT '责任人姓名',
                                     `db_schema` varchar(255) DEFAULT NULL COMMENT '模式',
                                     `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
                                     `is_edit` int DEFAULT '1' COMMENT '是否你能够编辑 0：不可以，1：可以',
                                     `custom_connect_properties` text,
                                     `jdbc_driver_jar_paths` text,
                                     `ds_name` varchar(100) DEFAULT NULL COMMENT '数据源名称',
                                     PRIMARY KEY (`id`),
                                     UNIQUE KEY `pool_name` (`pool_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci ROW_FORMAT=DYNAMIC;

drop table if exists report_table_category;
CREATE TABLE `report_table_category` (
                                         `id` int NOT NULL AUTO_INCREMENT COMMENT '主键 自增',
                                         `order_index` int DEFAULT '0' COMMENT '排序值，从小到大排',
                                         `datasource_id` int DEFAULT '0' COMMENT '数据源id',
                                         `category_name` varchar(50) NOT NULL COMMENT '指标分类名称',
                                         `remark` varchar(100) DEFAULT NULL COMMENT '备注',
                                         `create_time` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                         `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
                                         PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci ROW_FORMAT=DYNAMIC;


drop table if exists report_table_category_relation;
CREATE TABLE `report_table_category_relation` (
                                                  `id` int NOT NULL AUTO_INCREMENT COMMENT '主键 自增',
                                                  `order_index` int NOT NULL DEFAULT '0' COMMENT '排序值，从小到大排',
                                                  `category_id` int NOT NULL DEFAULT '0' COMMENT '分类id',
                                                  `table_view_name` varchar(50) NOT NULL COMMENT '视图表名称',
                                                  `table_comments` varchar(50) NOT NULL COMMENT '表中文名',
                                                  `tenant_id` varchar(12) DEFAULT NULL COMMENT '租户id',
                                                  `datasource_id` int DEFAULT NULL COMMENT '数据源ID',
                                                  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci ROW_FORMAT=DYNAMIC;


drop table if exists t_api;
CREATE TABLE `t_api` (
                         `api_id` int NOT NULL AUTO_INCREMENT COMMENT '编号',
                         `api_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '接口名称',
                         `url` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '请求地址',
                         `cgi_url` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                         `api_type_id` int DEFAULT NULL,
                         `call_limit` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '调用量限制',
                         `qps_limit` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT 'QPS限制',
                         `status` int DEFAULT NULL COMMENT '新- 状态  0 未发布  1 已发布    弃用-    0=免费使用 1=付费开通 2=测试使用 3=VIP使用',
                         `description` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '描述',
                         `version` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                         `doc_url` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                         `create_by` varchar(20) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                         `create_time` datetime DEFAULT NULL,
                         `update_time` datetime DEFAULT NULL,
                         `browser_count` int NOT NULL DEFAULT '0',
                         `ext_json` longtext CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci,
                         `apply_user_id` int DEFAULT NULL COMMENT '申请人id',
                         `mobile` varchar(20) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '联系方式',
                         `apply_status` int DEFAULT NULL COMMENT '申请状态：0未审核  1已审核 ',
                         `apply_time` datetime DEFAULT NULL COMMENT '申请时间',
                         `disagree_reason` varchar(500) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                         `is_apply` int DEFAULT NULL COMMENT '是否是申请新增：0否 1是',
                         `white_list` text COMMENT '白名单',
                         `black_list` text COMMENT '黑名单',
                         PRIMARY KEY (`api_id`)
) ENGINE=InnoDB AUTO_INCREMENT=163 DEFAULT CHARSET=utf8mb3 COMMENT='接口表';



drop table if exists t_api_auth_apply;
CREATE TABLE `t_api_auth_apply` (
                                    `id` int NOT NULL AUTO_INCREMENT,
                                    `user_id` int DEFAULT NULL COMMENT '用户ID\n',
                                    `api_id` int DEFAULT NULL COMMENT '接口id',
                                    `apply_use` varchar(500) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci NOT NULL COMMENT '申请用途',
                                    `status` int DEFAULT NULL COMMENT '审核状态:0 未审核、1 已审核',
                                    `apply_time` datetime DEFAULT NULL COMMENT '申请时间',
                                    `examine_user_id` int DEFAULT NULL COMMENT '审核用户ID\n',
                                    `examine_content` int DEFAULT NULL COMMENT '审核内容:0 不同意、0 已同意',
                                    `disagree_reason` varchar(500) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '不通过原因',
                                    `examine_time` datetime DEFAULT NULL COMMENT '审核时间',
                                    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='接口申请权限';



drop table if exists t_api_collect;
CREATE TABLE `t_api_collect` (
                                 `id` int NOT NULL AUTO_INCREMENT,
                                 `user_id` int DEFAULT NULL COMMENT '用户ID\n',
                                 `api_id` int DEFAULT NULL COMMENT '接口id',
                                 `is_collect` int DEFAULT NULL COMMENT '是否收藏:1 是、0 否',
                                 `create_time` datetime DEFAULT NULL,
                                 `modify_time` datetime DEFAULT NULL,
                                 PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='接口收藏';


drop table if exists t_api_log;
CREATE TABLE `t_api_log` (
                             `apilog_id` int NOT NULL AUTO_INCREMENT COMMENT '主键id',
                             `app_id` int DEFAULT NULL COMMENT '应用id',
                             `api_id` int DEFAULT NULL COMMENT '接口id',
                             `call_result` int DEFAULT NULL COMMENT '调用结果 1=成功 0=失败',
                             `invoke_time` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL,
                             `response_time` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '接口返回时间',
                             `img_url` varchar(500) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '图片路径',
                             `err_code` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '错误码',
                             `invoke_date` datetime DEFAULT NULL COMMENT '调用时间',
                             `user_id` int DEFAULT NULL COMMENT '用户id',
                             `user_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '用户姓名',
                             `params` varchar(2000) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                             `province` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '省份',
                             PRIMARY KEY (`apilog_id`,`invoke_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COMMENT='接口日志表';


drop table if exists t_api_log_day;
CREATE TABLE `t_api_log_day` (
                                 `user_id` int NOT NULL COMMENT '开发者id',
                                 `user_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '开发者名称',
                                 `app_id` int NOT NULL COMMENT '应用id',
                                 `app_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '应用名称',
                                 `api_id` int NOT NULL COMMENT '接口id',
                                 `api_name` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '应用名称',
                                 `total` int DEFAULT NULL COMMENT '调用成功次数',
                                 `failed` int DEFAULT NULL COMMENT '调用失败次数',
                                 `qps` int DEFAULT NULL COMMENT 'qps峰值',
                                 `day` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '日期'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COMMENT='接口日志--日表';

drop table if exists t_api_log_hour;
CREATE TABLE `t_api_log_hour` (
                                  `app_id` int NOT NULL COMMENT '应用id',
                                  `api_id` int NOT NULL COMMENT '接口id',
                                  `success` int DEFAULT NULL COMMENT '成功次数',
                                  `failed` int DEFAULT NULL COMMENT '失败次数',
                                  `qps` int DEFAULT NULL COMMENT 'qps峰值',
                                  `day` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '日期 yyyy-mm-dd hh:mm'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COMMENT='接口日志--时表';

drop table if exists t_api_log_test;
CREATE TABLE `t_api_log_test` (
                                  `apilog_id` int NOT NULL AUTO_INCREMENT,
                                  `app_id` int DEFAULT NULL,
                                  `api_id` int DEFAULT NULL,
                                  `call_result` int DEFAULT NULL,
                                  `invoke_time` bigint NOT NULL,
                                  `response_time` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                                  `img_url` varchar(500) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                                  `err_code` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                                  `invoke_date` datetime DEFAULT NULL,
                                  `user_id` int DEFAULT NULL,
                                  `user_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                                  `params` varchar(2000) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                                  PRIMARY KEY (`apilog_id`),
                                  KEY `api_id_index` (`api_id`) USING BTREE,
                                  KEY `app_id` (`app_id`) USING BTREE,
                                  KEY `call_result_index` (`call_result`) USING BTREE,
                                  KEY `err_code_index` (`err_code`) USING BTREE,
                                  KEY `ind2` (`call_result`,`invoke_time`) USING BTREE,
                                  KEY `ind_invoke_time` (`invoke_time`) USING BTREE,
                                  KEY `user_id` (`user_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3;

drop table if exists t_api_need_apply;
CREATE TABLE `t_api_need_apply` (
                                    `id` int NOT NULL AUTO_INCREMENT,
                                    `user_id` int DEFAULT NULL COMMENT '用户ID\n',
                                    `api_id` int DEFAULT NULL COMMENT '接口id',
                                    `mobile` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci NOT NULL COMMENT '联系方式',
                                    `field_json` varchar(1000) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci NOT NULL COMMENT '联系方式',
                                    `description` varchar(500) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci NOT NULL COMMENT '描述',
                                    `status` int DEFAULT NULL COMMENT '审核状态:审核状态:0 未审核、1 已审核待开发 2已审核已完成 3审核不通过',
                                    `apply_time` datetime DEFAULT NULL COMMENT '申请时间',
                                    `examine_user_id` int DEFAULT NULL COMMENT '审核用户ID\n',
                                    `disagree_reason` varchar(500) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '不通过原因',
                                    `examine_time` datetime DEFAULT NULL COMMENT '审核时间',
                                    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='接口申请开发';

drop table if exists t_api_type;
CREATE TABLE `t_api_type` (
                              `apitype_id` int NOT NULL AUTO_INCREMENT COMMENT '编号',
                              `type_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '类型名称',
                              `description` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '备注',
                              PRIMARY KEY (`apitype_id`)
) ENGINE=InnoDB AUTO_INCREMENT=34 DEFAULT CHARSET=utf8mb3 COMMENT='接口类型表';


drop table if exists t_api_version;
CREATE TABLE `t_api_version` (
                                 `id` int NOT NULL AUTO_INCREMENT,
                                 `api_id` int NOT NULL,
                                 `old_version` varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL,
                                 `create_time` datetime DEFAULT NULL,
                                 `create_by` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL,
                                 `remark` varchar(500) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL,
                                 PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

drop table if exists t_app;
CREATE TABLE `t_app` (
                         `app_id` int NOT NULL AUTO_INCREMENT COMMENT '编号',
                         `name` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '应用名称',
                         `user_id` int NOT NULL COMMENT '关联用户id',
                         `app_type_id` int NOT NULL COMMENT '应用类型id',
                         `api_key` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT 'API Key',
                         `secret_key` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT 'Secret Key',
                         `create_time` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '创建时间',
                         `update_time` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '更新时间',
                         `status` int DEFAULT NULL COMMENT '应用状态（1=正常 0=停用 2=待审核）',
                         `description` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '应用描述',
                         `expire_date` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '到期日期',
                         PRIMARY KEY (`app_id`)
) ENGINE=InnoDB AUTO_INCREMENT=319 DEFAULT CHARSET=utf8mb3 COMMENT='应用表';

drop table if exists t_app_api;
CREATE TABLE `t_app_api` (
                             `appapi_id` int NOT NULL AUTO_INCREMENT COMMENT '主键id',
                             `app_id` int NOT NULL COMMENT '应用id',
                             `api_id` int NOT NULL COMMENT '接口id',
                             `enable` int NOT NULL COMMENT '启用/停用  0 启用 1 停用',
                             `status` int NOT NULL COMMENT '状态 0=待审核 1=正常使用 2=待支付 3=停用',
                             `call_limit` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '调用量限制',
                             `qps_limit` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT 'QPS限制',
                             `qps_apply_id` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '更高QPS申请id',
                             `used` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                             PRIMARY KEY (`appapi_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COMMENT='接口权限表';

drop table if exists t_app_type;
CREATE TABLE `t_app_type` (
                              `apptype_id` int NOT NULL AUTO_INCREMENT COMMENT '主键id',
                              `type_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '应用类型名称',
                              `description` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '备注',
                              PRIMARY KEY (`apptype_id`)
) ENGINE=InnoDB AUTO_INCREMENT=28 DEFAULT CHARSET=utf8mb3 COMMENT='应用类型表';

drop table if exists t_auth;
CREATE TABLE `t_auth` (
                          `auth_id` int NOT NULL AUTO_INCREMENT COMMENT '权限id',
                          `role_id` int NOT NULL COMMENT '角色id',
                          `api_id` int NOT NULL COMMENT '接口id',
                          `accredit_status` int NOT NULL COMMENT '授权状态 0 未授权 1 已授权 2 待授权',
                          `apply_time` datetime DEFAULT NULL COMMENT '申请授权时间',
                          `user_id` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '申请人id',
                          PRIMARY KEY (`auth_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3;

drop table if exists t_code_info;
CREATE TABLE `t_code_info` (
                               `err_code` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '错误码',
                               `err_detail` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '错误详情',
                               `err_description` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '错误描述',
                               `feedback` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '处理意见',
                               KEY `err_code_index` (`err_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3;

drop table if exists t_qps_apply;
CREATE TABLE `t_qps_apply` (
                               `qps_id` int NOT NULL AUTO_INCREMENT COMMENT '编号',
                               `max_qps` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '预估最高QPS',
                               `call_times` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '预估每日调用量',
                               `areas` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '接入地域比例',
                               `company_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '公司名称',
                               `phone` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '联系电话',
                               `email` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '联系邮箱',
                               `description` varchar(2000) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '应用介绍',
                               `apply_reason` varchar(1000) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '提升配额原因',
                               `apply_status` tinyint DEFAULT NULL COMMENT '申请状态 0=默认配额 1=审核通过 2=审核中 3=审核拒绝',
                               PRIMARY KEY (`qps_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COMMENT='更高QPS申请';

drop table if exists t_role;
CREATE TABLE `t_role` (
                          `role_id` int NOT NULL AUTO_INCREMENT,
                          `role_name` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '角色名字',
                          `role_type` int NOT NULL COMMENT '角色类型',
                          `description` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '备注',
                          PRIMARY KEY (`role_id`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8mb3 COMMENT='角色表';

drop table if exists t_sms_log;
CREATE TABLE `t_sms_log` (
                             `sms_id` int NOT NULL AUTO_INCREMENT,
                             `phone` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '电话号码',
                             `code` varchar(20) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '验证码',
                             `create_time` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '创建时间',
                             `status` tinyint NOT NULL COMMENT '状态',
                             PRIMARY KEY (`sms_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3;

drop table if exists t_system_log;
CREATE TABLE `t_system_log` (
                                `id` int NOT NULL AUTO_INCREMENT,
                                `log_account` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '日志账号',
                                `log_content` varchar(200) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '日志内容',
                                `log_ip` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT 'ip地址',
                                `log_time` datetime DEFAULT NULL COMMENT '日期时间',
                                PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb3 COMMENT='系统日志表';

drop table if exists t_user;
CREATE TABLE `t_user` (
                          `user_id` int NOT NULL AUTO_INCREMENT,
                          `user_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '姓名',
                          `account` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '账号',
                          `phone` varchar(30) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '电话',
                          `password_hash` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '密码',
                          `email` varchar(50) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL COMMENT '邮箱',
                          `status` int DEFAULT NULL COMMENT '用户状态（1=免费用户 0=异常用户 2=付费用户 3=VIP用户 4=测试用户)',
                          `role_id` int NOT NULL COMMENT '角色',
                          `description` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL COMMENT '备注',
                          `company_name` varchar(100) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                          `company_info` varchar(1000) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT NULL,
                          PRIMARY KEY (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=71 DEFAULT CHARSET=utf8mb3 COMMENT='用户表';


INSERT INTO t_role(role_id, role_name, role_type, description)VALUES(1, '管理员', 1, NULL);
INSERT INTO t_role(role_id, role_name, role_type, description)VALUES(2, '开发者', 2, '123');

INSERT INTO t_user(user_id, user_name, account, phone, password_hash, email, status, role_id, description, company_name, company_info)
VALUES(1, '平台管理员', 'admin', '13382890928', 'a3f4c511243abf2522465a603ab46f53', '536818@qq.com', 1, 1, NULL, NULL, NULL);
INSERT INTO t_user(user_id, user_name, account, phone, password_hash, email, status, role_id, description, company_name, company_info)
VALUES(2, '测试开发者', 'test', '13771111749', 'e10adc3949ba59abbe56e057f20f883e', '88933120@qq.com', 1, 2, '12', 'null', 'null');
